permission.utils package
========================

Submodules
----------

permission.utils.autodiscover module
------------------------------------

.. automodule:: permission.utils.autodiscover
    :members:
    :undoc-members:
    :show-inheritance:

permission.utils.handlers module
--------------------------------

.. automodule:: permission.utils.handlers
    :members:
    :undoc-members:
    :show-inheritance:

permission.utils.logics module
------------------------------

.. automodule:: permission.utils.logics
    :members:
    :undoc-members:
    :show-inheritance:

permission.utils.permissions module
-----------------------------------

.. automodule:: permission.utils.permissions
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: permission.utils
    :members:
    :undoc-members:
    :show-inheritance:
